[link](http://foo.bar)
[link](http://foo.bar) this also

---

And [this](http://foo.com) is also [a](http://foo.bar) link

- And [this](http://foo.com) is also [a](http://foo.bar) link
- And [this](http://foo.com) is also [a](http://foo.bar) link

---

[link *with* **formatting** and `code`](http://foo.bar)
